Event Type
==========

The :class:`DtEventType` class is utilized to define the type event as
ingested through the Events V2 API.
This enum can only be used in the context of a event ingestion when
calling the :meth:`dynatrace_extension.Extension.report_dt_event` method.

Members
^^^^^^^

.. autoclass:: dynatrace_extension.DtEventType
   :members:
   :undoc-members:
